.. _io.tbtrans:

TBtrans
=======

.. module:: sisl.io.tbtrans

.. autosummary::
   :toctree: generated/

   tbtncSileTBtrans
   deltancSileTBtrans
   tbtgfSileTBtrans - TBtrans surface Green function files
   tbtsencSileTBtrans
   tbtavncSileTBtrans
   tbtprojncSileTBtrans

.. autosummary::
   :toctree: generated/
   :hidden:

   SileTBtrans
   SileCDFTBtrans
   SileBinTBtrans

PHtrans
=======

`TBtrans`_ is per default a ballistic electron transport utility. It may also
be compiled in a ballistic phonon transport mode, named ``PHtrans``.

.. autosummary::
   :toctree: generated/

   phtncSilePHtrans
   phtsencSilePHtrans
   phtavncSilePHtrans
   phtprojncSilePHtrans
